@@ -10,7 +10,7 @@ from coba.exceptions import CobaException
 from coba.environments.filters     import EnvironmentFilter
 from coba.environments.filters     import Binary, Shuffle, Take, Sparse, Reservoir, Cycle, Scale
 from coba.environments.filters     import Impute, Where, Noise, Riffle, Sort
-from coba.environments.definitions import EnvironmentDefinitionFileV1
+from coba.environments.templates import EnvironmentsTemplateV1, EnvironmentsTemplateV2
 
 from coba.environments          .primitives import Environment
 from coba.environments.logged   .primitives import LoggedEnvironment
@@ -27,16 +27,26 @@ class Environments:
 
     @overload
     @staticmethod
-    def from_file(filesource:Source[Iterable[str]]) -> 'Environments': ...
+    def from_template(filesource:Source[Iterable[str]]) -> 'Environments': ...
 
     @overload
     @staticmethod
-    def from_file(filename:str) -> 'Environments': ...
+    def from_template(fileurl:str) -> 'Environments': ...
 
     @staticmethod
-    def from_file(arg) -> 'Environments':
-        """Instantiate Environments from an environments definition file."""
-        return Environments(*EnvironmentDefinitionFileV1(arg).read())
+    def from_template(arg, **user_vars) -> 'Environments':
+        """Instantiate Environments from an environment template file with user defined variables."""
+        try:
+            return Environments(*EnvironmentsTemplateV2(arg, **user_vars).read())
+        except Exception as e: #pragma: no cover
+            try:
+                #try previous version of definition files. If previous versions also fail
+                #then we raise the exception given by the most up-to-date version so that
+                #changes can be made to conform to the latest version.
+                return Environments(*EnvironmentsTemplateV1(arg).read())
+            except:
+                raise e
+
 
     @staticmethod
     def from_prebuilt(name:str) -> 'Environments':
@@ -57,7 +67,7 @@ class Environments:
         definition_txt = definition_txt.replace('"./', f'"{repo_url}/{name}/')
         definition_txt = definition_txt.replace('.json"', '.json?raw=True"')
 
-        return Environments.from_file(ListSource([definition_txt]))
+        return Environments.from_template(ListSource([definition_txt]))
 
     @staticmethod
     def from_linear_synthetic(
@@ -138,6 +148,7 @@ class Environments:
     @staticmethod
     def from_openml(data_id: Union[int,Sequence[int]],
         cat_as_str: bool = False,
+        drop_missing: bool = True,
         take: int = None) -> 'Environments':
         ...
 
@@ -145,6 +156,7 @@ class Environments:
     @staticmethod
     def from_openml(*,task_id: Union[int,Sequence[int]],
         cat_as_str: bool = False,
+        drop_missing: bool = True,
         take: int = None) -> 'Environments':
         ...
 
@@ -152,7 +164,7 @@ class Environments:
     def from_openml(*args,**kwargs) -> 'Environments':
         """Create a SimulatedEnvironment from datasets available on openml."""
 
-        kwargs.update(zip(['data_id','cat_as_str','take'], args))
+        kwargs.update(zip(['data_id','cat_as_str','drop_missing','take'], args))
 
         if 'data_id' in kwargs and isinstance(kwargs['data_id'],int):
             kwargs['data_id'] = [kwargs['data_id']]
